==> graphql-web-lite-16.6.0-3.tgz: package/utilities/separateOperations.js <==
var shared = require("../shared.js");

function collectTransitiveDependencies(collected, depGraph, fromName) {
  if (!collected.has(fromName)) {
    collected.add(fromName);
    const immediateDeps = depGraph[fromName];
    if (void 0 !== immediateDeps) {
      for (const toName of immediateDeps) {
        collectTransitiveDependencies(collected, depGraph, toName);
      }
    }
  }
}

function collectDependencies(selectionSet) {
  const dependencies = [];
  shared.visit(selectionSet, {
    FragmentSpread(node) {
      dependencies.push(node.name.value);
    }
  });
  return dependencies;
}

exports.separateOperations = function separateOperations(documentAST) {
  const operations = [];
  const depGraph = Object.create(null);
  for (const definitionNode of documentAST.definitions) {
    switch (definitionNode.kind) {
     case shared.e.OPERATION_DEFINITION:
      operations.push(definitionNode);
      break;

     case shared.e.FRAGMENT_DEFINITION:
      depGraph[definitionNode.name.value] = collectDependencies(definitionNode.selectionSet);
    }
  }
  const separatedDocumentASTs = Object.create(null);
  for (const operation of operations) {
    const dependencies = new Set;
    for (const fragmentName of collectDependencies(operation.selectionSet)) {
      collectTransitiveDependencies(dependencies, depGraph, fragmentName);
    }
    separatedDocumentASTs[operation.name ? operation.name.value : ""] = {
      kind: shared.e.DOCUMENT,
      definitions: documentAST.definitions.filter((node => node === operation || node.kind === shared.e.FRAGMENT_DEFINITION && dependencies.has(node.name.value)))
    };
  }
  return separatedDocumentASTs;
};

==> graphql-web-lite-16.6.0-4.tgz: package/utilities/separateOperations.js <==
var graphql_web = require("@0no-co/graphql.web");

function collectTransitiveDependencies(collected, depGraph, fromName) {
  if (!collected.has(fromName)) {
    collected.add(fromName);
    const immediateDeps = depGraph[fromName];
    if (void 0 !== immediateDeps) {
      for (const toName of immediateDeps) {
        collectTransitiveDependencies(collected, depGraph, toName);
      }
    }
  }
}

function collectDependencies(selectionSet) {
  const dependencies = [];
  graphql_web.visit(selectionSet, {
    FragmentSpread(node) {
      dependencies.push(node.name.value);
    }
  });
  return dependencies;
}

exports.separateOperations = function separateOperations(documentAST) {
  const operations = [];
  const depGraph = Object.create(null);
  for (const definitionNode of documentAST.definitions) {
    switch (definitionNode.kind) {
     case graphql_web.Kind.OPERATION_DEFINITION:
      operations.push(definitionNode);
      break;

     case graphql_web.Kind.FRAGMENT_DEFINITION:
      depGraph[definitionNode.name.value] = collectDependencies(definitionNode.selectionSet);
    }
  }
  const separatedDocumentASTs = Object.create(null);
  for (const operation of operations) {
    const dependencies = new Set;
    for (const fragmentName of collectDependencies(operation.selectionSet)) {
      collectTransitiveDependencies(dependencies, depGraph, fragmentName);
    }
    separatedDocumentASTs[operation.name ? operation.name.value : ""] = {
      kind: graphql_web.Kind.DOCUMENT,
      definitions: documentAST.definitions.filter((node => node === operation || node.kind === graphql_web.Kind.FRAGMENT_DEFINITION && dependencies.has(node.name.value)))
    };
  }
  return separatedDocumentASTs;
};
